## colon	R Documentation
## Chemotherapy for Stage B/C colon cancer
## Description

## These are data from one of the first successful trials of adjuvant
## chemotherapy for colon cancer. Levamisole is a low-toxicity compound
## previously used to treat worm infestations in animals; 5-FU is a
## moderately toxic (as these things go) chemotherapy agent. There are
## two records per person, one for recurrence and one for death

## Usage

## colon

## Format
## id:	id
## study:	1 for all patients
## rx:	Treatment - Obs(ervation), Lev(amisole), Lev(amisole)+5-FU
## sex:	1=male
## age:	in years
## obstruct:	obstruction of colon by tumour
## perfor:	perforation of colon
## adhere:	adherence to nearby organs
## nodes:	number of lymph nodes with detectable cancer
## time:	days until event or censoring
## status:	censoring status
## differ:	differentiation of tumour (1=well, 2=moderate, 3=poor)
## extent:	Extent of local spread (1=submucosa, 2=muscle, 3=serosa, 4=contiguous structures)
## surg:	time from surgery to registration (0=short, 1=long)
## node4:	more than 4 positive lymph nodes
## etype:	event type: 1=recurrence,2=death
## Note

## The study is originally described in Laurie (1989). The main report is
## found in Moertel (1990). This data set is closest to that of the final
## report in Moertel (1991). A version of the data with less follow-up
## time was used in the paper by Lin (1994).

##References
## JA Laurie, CG Moertel, TR Fleming, HS Wieand, JE Leigh, J Rubin, GW
## McCormack, JB Gerstner, JE Krook and J Malliard. Surgical adjuvant
## therapy of large-bowel carcinoma: An evaluation of levamisole and the
## combination of levamisole and fluorouracil: The North Central Cancer
## Treatment Group and the Mayo Clinic. J Clinical Oncology, 7:1447-1456,
## 1989.

## DY Lin. Cox regression analysis of multivariate failure time data: the
## marginal approach. Statistics in Medicine, 13:2233-2247, 1994.

## CG Moertel, TR Fleming, JS MacDonald, DG Haller, JA Laurie, PJ
## Goodman, JS Ungerleider, WA Emerson, DC Tormey, JH Glick, MH Veeder
## and JA Maillard. Levamisole and fluorouracil for adjuvant therapy of
## resected colon carcinoma. New England J of Medicine, 332:352-358,
## 1990.

## CG Moertel, TR Fleming, JS MacDonald, DG Haller, JA Laurie, CM Tangen,
## JS Ungerleider, WA Emerson, DC Tormey, JH Glick, MH Veeder and JA
## Maillard, Fluorouracil plus Levamisole as an effective adjuvant
## therapy after resection of stage II colon carcinoma: a final
## report. Annals of Internal Med, 122:321-326, 1991.

library(survival)
data(colon)

attach(colon)


## Careful: two measurements per subject: time to recurrence (etype==1)  and time to death (etype==2)
## Let us focus on recurrence free survival time (<etype==1>)  (Note: etype==2 is death)
##  (Note: etype==2 is death)
colon2 = subset(colon,(etype==1)&(!is.na(nodes))&(!is.na(differ)))


obsTime = colon2$time/365
delta = colon2$status

plot(survfit(Surv(obsTime,status)~rx,data=colon2),col=c("black","red","blue"),lty=1:3,lwd=2,xlim=c(0,9.5),mark.time=T)
legend("topright",legend=names(table(colon2$rx)),col=c("black","red","blue"),lty=1:3,lwd=2)
## plot(survfit(Surv(obsTime,status)~rx,data=colon2),col=1:3,lty=1:3,lwd=2)
## legend("topright",legend=names(table(colon2$rx)),col=1:3,lty=1:3,lwd=2)

TrtLev = ifelse(colon2$rx=="Lev",1,0)
TrtLev5FU = ifelse(colon2$rx=="Lev+5FU",1,0)

Male = colon2$sex

Age = colon2$age
Agec = (Age-mean(Age))/sd(Age)

Obstruct = colon2$obstruct
Perfor = colon2$perfor
Adhere = colon2$adhere

Nodes = colon2$nodes
Nodes.cat = cut(Nodes,breaks=c(-1,1,2,5,max(Nodes)))
plot(survfit(Surv(obsTime,status)~Nodes.cat,data=colon2),col=1:4,lty=1:4,lwd=2)
legend("topright",legend=names(table(Nodes.cat)),col=1:4,lty=1:4,lwd=2)
##
Nodes1 = 0+(Nodes<=1) # Reference category
Nodes2 = 0+(Nodes==2)
Nodes3 = 0+(Nodes>2)*(Nodes<=5)
Nodes4 = 0+(Nodes>5)

DifferPoor = ifelse(colon2$differ==3,1,0)
plot(survfit(Surv(obsTime,status)~differ,data=colon2),col=1:3,lty=1:3,lwd=2)
legend("topright",legend=names(table(colon2$differ)),col=1:3,lty=1:3,lwd=2)

Extent12 = ifelse(colon2$extent<=2,1,0)
Extent3 = ifelse(colon2$extent==3,1,0) ## Reference
Extent4 = ifelse(colon2$extent==4,1,0)



